#!/usr/bin/python
#//////////////////////////////////////////////////////////////////////////////
#
# Copyright (c) 2007,2009 Daniel Adler <dadler@uni-goettingen.de>, 
#                         Tassilo Philipp <tphilipp@potion-studios.com>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#//////////////////////////////////////////////////////////////////////////////

import sys

f = file("design.cfg")

sigmap = { 
  'B':'DCbool'
, 'c':'DCchar'
, 's':'DCshort'
, 'i':'DCint'
, 'l':'DClonglong'
, 'f':'DCfloat'
, 'd':'DCdouble'
, 'p':'DCpointer'
}

apimap = {
  '_':''
, 's':'__declspec(stdcall)'
, 'f':'__declspec(fastcall)'
}

id = 0
maxargs = 0
sys.stdout.write("/* auto generated by mkcase.py (on stdout) */\n");
for line in f: 
  line = line.rstrip().lstrip()
  if len(line) == 0 or line[0] == '#': continue
  types = [];
  # args  = len(line)-1
  args = len(line)
  maxargs = max(maxargs, args)
  # api = apimap[ line[0] ]
  out = [ "VF",str(args),"(", str(id), "," ];
  for i in xrange(0,len(line)):   
    types += [ sigmap[ line[i] ] ]
  out += [ ",".join( types ), ",s_", line, ")\n" ]
  out = "".join(out)
  sys.stdout.write(out)
  id  += 1

sys.stderr.write("/* auto generated by mkcase (on stderr) */\n");
sys.stderr.write("".join( ["#define NCASES ",str(id),"\n"] ) )
sys.stderr.write("".join( ["#define MAXARGS ",str(maxargs),"\n"] ) )






#!/usr/bin/python
#//////////////////////////////////////////////////////////////////////////////
#
# Copyright (c) 2007,2009 Daniel Adler <dadler@uni-goettingen.de>, 
#                         Tassilo Philipp <tphilipp@potion-studios.com>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#//////////////////////////////////////////////////////////////////////////////

import sys

# parameters

nargs  = 3

types  = ["DCbool","DCint","DClonglong","DCdouble","DCpointer","DCfloat"]

# generator

ntypes = len(types)

sys.stderr.write("/* auto generated by mkcase (on stderr) */\n");
sys.stderr.write("".join(["#define NARGS  ",str(nargs),"\n"]))
sys.stderr.write("".join(["#define NTYPES ",str(ntypes),"\n"]))

def powerfact(x, n):
  if n==0:
    return 0
  else:
    return x**n+powerfact(x,n-1)

x     = 0
end   = powerfact(ntypes,nargs)+1

sys.stdout.write("/* auto generated by mkcase.py (on stdout) */\n");

while x < end:
  args = [str(x)]
  sig  = ["f_"]
  pos  = 0
  y    = x
  while y > 0:
    s     = (y-1) % ntypes
    y     = (y-1) / ntypes
    args += [ types[s] ]
    sig  += [ types[s][2] ]
    pos  += 1
  sig   = "".join(sig)
  args += [ sig ]
  args  = ",".join(args)
  sys.stdout.write( "".join(["VF",str(pos),"(",args,")\n"]) )
  x += 1




#!/usr/bin/python
#//////////////////////////////////////////////////////////////////////////////
#
# Copyright (c) 2007,2009 Daniel Adler <dadler@uni-goettingen.de>, 
#                         Tassilo Philipp <tphilipp@potion-studios.com>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#//////////////////////////////////////////////////////////////////////////////


import random
import sys

N = 1000
MINARG = 0
MAXARG = 19

argtypes = [ 'B','c','s','i','l','f','d','p' ]
apitypes = [ '_' ]

def sig(n):
  s = ""
  x = random.randint( 0, len(apitypes)-1 )
  # s += apitypes[x]
  for i in xrange(0,n):
    x = random.randint( 0, len(argtypes)-1 )
    s += argtypes[x]
  return s

for i in xrange(0,N):
  n = random.randint(MINARG,MAXARG)
  sys.stdout.write( sig(n) )
  sys.stdout.write( "\n" )

